#!perl -w
use strict;
use Test::Simple tests => 13;
use DE_EPAGES::Core::API::File qw( DeleteFile );
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Object::API::XMLCompare qw ( CompareXML );
use DE_EPAGES::Object::API::XMLStructureImportHandler;
use DE_EPAGES::Object::API::XMLStructureExportDriver;

my $ExportFileName = 'Temp.xml';
my $TranslationFileName = 'Translation.Tmp.tt.xml';

RunScript(Sub => sub {
    ok(CleanUp(), 'CleanUp');

    my $ImportHandler = DE_EPAGES::Object::API::XMLStructureImportHandler->new();
    my $ExportDriver = DE_EPAGES::Object::API::XMLStructureExportDriver->new();

    my $XML = 'AttributesObject.xml';
    my $XMLStruct = $ImportHandler->getXMLStructure($XML);
    $ExportDriver->exportXML($ExportFileName, $XMLStruct);
    ok(
        (
            CompareXML($XML, $ExportFileName, {'printmessage' => '1'}) and
            CompareXML($ExportFileName, $XML, {'printmessage' => '1'})
        )
        , "$XML export and original xml are equal"
    );

    $XML = 'AttributesSystem.xml';
    $XMLStruct = $ImportHandler->getXMLStructure($XML);
    $ExportDriver->exportXML($ExportFileName, $XMLStruct);
    ok(
        (
            CompareXML($XML, $ExportFileName, {'printmessage' => '1'}) and
            CompareXML($ExportFileName, $XML, {'printmessage' => '1'})
        )
        , "$XML export and original xml are equal"
    );

    $XML = 'Dependencies.xml';
    $XMLStruct = $ImportHandler->getXMLStructure($XML);
    $ExportDriver->exportXML($ExportFileName, $XMLStruct);
    ok(
        (
            CompareXML($XML, $ExportFileName, {'printmessage' => '1'}) and
            CompareXML($ExportFileName, $XML, {'printmessage' => '1'})
        )
        , "$XML export and original xml are equal"
    );

    $XML = 'HooksObject.xml';
    $XMLStruct = $ImportHandler->getXMLStructure($XML);
    $ExportDriver->exportXML($ExportFileName, $XMLStruct);
    ok(
        (
            CompareXML($XML, $ExportFileName, {'printmessage' => '1'}) and
            CompareXML($ExportFileName, $XML, {'printmessage' => '1'})
        )
        , "$XML export and original xml are equal"
    );

    $XML = 'HooksPreDefAttribute.xml';
    $XMLStruct = $ImportHandler->getXMLStructure($XML);
    $ExportDriver->exportXML($ExportFileName, $XMLStruct);
    ok(
        (
            CompareXML($XML, $ExportFileName, {'printmessage' => '1'}) and
            CompareXML($ExportFileName, $XML, {'printmessage' => '1'})
        )
        , "$XML export and original xml are equal"
    );

    #$XML = 'Languages.xml';
    #$XMLStruct = $ImportHandler->getXMLStructure($XML);
    #$ExportDriver->exportXML($ExportFileName, $XMLStruct);
    #ok(
    #    (
    #        CompareXML($XML, $ExportFileName, {'printmessage' => '1'}) and
    #        CompareXML($ExportFileName, $XML, {'printmessage' => '1'})
    #    )
    #    , "$XML export and original xml are equal"
    #);

    $XML = 'Locales.xml';
    $XMLStruct = $ImportHandler->getXMLStructure($XML);
    $ExportDriver->exportXML($ExportFileName, $XMLStruct);
    ok(
        (
            CompareXML($XML, $ExportFileName, {'printmessage' => '1'}) and
            CompareXML($ExportFileName, $XML, {'printmessage' => '1'})
        )
        , "$XML export and original xml are equal"
    );

    $XML = 'System.xml';
    $XMLStruct = $ImportHandler->getXMLStructure($XML);
    $ExportDriver->exportXML($ExportFileName, $XMLStruct);
    ok(
        (
            CompareXML($XML, $ExportFileName, {'printmessage' => '1'}) and
            CompareXML($ExportFileName, $XML, {'printmessage' => '1'})
        )
        , "$XML export and original xml are equal"
    );

    $XML = 'Translation_Attributes_de.xml';
    $XMLStruct = $ImportHandler->getXMLStructure($XML);
    $ExportDriver->exportXML($TranslationFileName, $XMLStruct);
    ok(
        (
            CompareXML($XML, $TranslationFileName, {'printmessage' => '1'}) and
            CompareXML($TranslationFileName, $XML, {'printmessage' => '1'})
        )
        , "$XML export and original xml are equal"
    );

    $XML = 'UnitsOfMeasurement.xml';
    $XMLStruct = $ImportHandler->getXMLStructure($XML);
    $ExportDriver->exportXML($ExportFileName, $XMLStruct);
    ok(
        (
            CompareXML($XML, $ExportFileName, {'printmessage' => '1'}) and
            CompareXML($ExportFileName, $XML, {'printmessage' => '1'})
        )
        , "$XML export and original xml are equal"
    );

    ok(
        not(
            CompareXML('System.xml', $ExportFileName,) and
            CompareXML($ExportFileName, 'System.xml',)
        )
        , 'export and control xml are not equal'
    );

    my $TestTranslationXML = sub {
        my ($Old, $Diff, $New, $NoEmptyOverwrite) = @_;

        $XMLStruct = $ImportHandler->getXMLStructure($Old, {'register_notrans' => 1});
        my $XMLDiff = $ImportHandler->getXMLStructure($Diff, {'register_notrans' => 1});
        $XMLStruct->assimilateXMLStructure($XMLDiff, {'overwrite' => 1, 'overwrite_empty_tagtext' => $NoEmptyOverwrite});
        $ExportDriver->exportXML($TranslationFileName, $XMLStruct);
        ok(
            (
                CompareXML($New, $TranslationFileName, {'printmessage' => '1'}) and
                CompareXML($TranslationFileName, $New, {'printmessage' => '1'})
            )
            , "$New and $TranslationFileName are equal"
        );
    };

    $TestTranslationXML->('Dictionary_attributes_old.en.xml', 'Dictionary_attributes_imp.en.xml',
        'Dictionary_attributes_new.en.xml', 0);
    $TestTranslationXML->('Dictionary_attributes_old.en.xml', 'Dictionary_attributes_imp.en.xml',
        'Dictionary_attributes_new_empty.en.xml', 1);

}, Debug=>1);

sub CleanUp {
    DeleteFile( $ExportFileName );
    DeleteFile( $TranslationFileName );
    return 1;
}
1;